@@ -19,7 +19,7 @@
 #' fs <- list(fa, fb, fab)
 #' fct_c(!!!fs)
 fct_c <- function(...) {
-  fs <- rlang::list2(...)
+  fs <- list2(...)
   fs <- check_factor_list(fs, "...")
 
   if (length(fs) == 0) {
@@ -42,6 +42,7 @@ fct_c <- function(...) {
 #' fct_unify(fs)
 fct_unify <- function(fs, levels = lvls_union(fs)) {
   fs <- check_factor_list(fs)
+  check_character(levels)
 
   lapply(fs, lvls_expand, new_levels = levels)
 }
