@@ -17,7 +17,12 @@
 #'   dem = c("Not str democrat", "Strong democrat")
 #' )
 #' fct_count(partyid2)
-fct_collapse <- function(.f, ..., other_level = NULL, group_other = "DEPRECATED") {
+fct_collapse <- function(
+  .f,
+  ...,
+  other_level = NULL,
+  group_other = "DEPRECATED"
+) {
   f <- check_factor(.f)
   check_string(other_level, allow_null = TRUE, allow_na = TRUE)
 
