@@ -63,7 +63,11 @@ fct_relevel <- function(.f, ..., after = 0L) {
     first_levels <- intersect(first_levels, old_levels)
   }
 
-  new_levels <- append(setdiff(old_levels, first_levels), first_levels, after = after)
+  new_levels <- append(
+    setdiff(old_levels, first_levels),
+    first_levels,
+    after = after
+  )
 
   lvls_reorder(f, match(new_levels, old_levels))
 }
